<?php

namespace Drupal\twitter_api;

use Drupal\Core\Config\ConfigFactoryInterface;
use GuzzleHttp\Client;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Subscriber\Oauth\Oauth1;

/**
 * Factory for creating an HTTP client.
 */
class HttpClientFactory {

  /**
   * Creates a new HTTP Client.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory
  ) {
  }

  /**
   * Creates an HTTP client.
   *
   * @return \GuzzleHttp\ClientInterface
   *   The HTTP client.
   */
  public function createClient(): ClientInterface {
    $stack = HandlerStack::create();

    $config = $this->configFactory->get('twitter_api.settings');

    $middleware = new Oauth1([
      'consumer_key' => $config->get('consumer_key'),
      'consumer_secret' => $config->get('consumer_secret'),
      'token' => $config->get('oauth_access_token'),
      'token_secret' => $config->get('oauth_access_token_secret'),
    ]);
    $stack->push($middleware);

    $baseUri = rtrim($config->get('api_url'), ' /') . '/';

    return new Client([
      'base_uri' => $baseUri,
      'handler' => $stack,
      'auth' => 'oauth'
    ]);
  }

}
