<?php

namespace Drupal\twitter_api;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Utility\Error;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;
use Psr\Log\LoggerInterface;

/**
 * Class TwitterApiClient.
 *
 * Drupal wrapper for TwitterAPIExchange.
 */
class TwitterApiClient implements TwitterApiClientInterface {

  /**
   * TwitterApiClient constructor.
   */
  public function __construct(
    protected ClientInterface $httpClient,
    protected LoggerInterface $logger
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public function doGet(string $end_point, array $query_params): array {
    try {
      $response = $this->httpClient->request('GET', $end_point, ['query' => $query_params]);
    }
    catch (GuzzleException $e) {
      $this->logger->error(Error::DEFAULT_ERROR_MESSAGE, Error::decodeException($e));
      return [];
    }
    if ($response->getStatusCode() != 200) {
      $this->logger->error("Failed to query twitter api %code %message", [
        '%code' => $response->getStatusCode(),
        '%message' => $response->getReasonPhrase(),
      ]);
      return [];
    }
    return Json::decode($response->getBody());
  }

  /**
   * {@inheritdoc}
   */
  public function getTweets(array $params): array {
    return $this->doGet('statuses/user_timeline.json', $params);
  }

}
